Struct libp2p_websocket::WsConfig
source · pub struct WsConfig<T> { /* private fields */ }Expand description
Represents the configuration for a websocket transport capability for libp2p. Must be put on
top of another Transport.
This implementation of Transport accepts any address that ends with /ws or /wss, and will
try to pass the underlying multiaddress to the underlying Transport.
Note that the underlying multiaddr is /dns4/... or /dns6/..., then this library will
pass the domain name in the headers of the request. This is important is the listener is behind
an HTTP proxy.
Note:
/wssis only supported for dialing and not listening.
Implementations